@@ -120,6 +120,14 @@ class _UIFabric(object):
     """
     pack_method = ''  # для метода для расширения UI
     pack_flag = ''  # флаг расширения UI простым путём (напр.для справочников)
+    """
+    pack_flag может быть вида
+    {
+        'icon': 'icon-cls', 
+        'index': 101
+    }
+    тогда автоматом проставится иконка и порядок также будет учитываться
+    """
     # метод расширения UI (_add_to_XXX, обернутый в staticmethod, если нужно)
     ui_extend_method = lambda *args: None
 
@@ -175,8 +183,21 @@ class _UIFabric(object):
         """
         try:
             assert pack.title
-            if getattr(pack, self.pack_flag, False):
-                return self.Item(name=pack.title, pack=pack)
+
+            flag = getattr(pack, self.pack_flag, False)
+            if flag:
+                if isinstance(flag, dict):
+                    return self.Item(
+                        name=pack.title,
+                        pack=pack,
+                        # default-launcher из m3_ext.ui.app_ui.DesktopLauncher
+                        icon=flag.get('icon', 'default-launcher'),
+                        # 100 из m3_ext.ui.app_ui.DesktopLauncher                        
+                        index=flag.get('index', 100))
+                else:
+                    return self.Item(
+                        name=pack.title,
+                        pack=pack)
             else:
                 return None
         except (AttributeError, AssertionError):
