@@ -27,6 +27,8 @@ class TreeObjectPack(objectpack.ObjectPack):
     def __init__(self, *args, **kwargs):
         super(TreeObjectPack, self).__init__(*args, **kwargs)
         self.replace_action('rows_action', TreeObjectRowsAction())
+        self.autocomplete_action = objectpack.ObjectRowsAction()
+        self.actions.append(self.autocomplete_action)
 
     def get_rows_query(self, request, context):
         result = super(TreeObjectPack, self).get_rows_query(request, context)
@@ -80,6 +82,9 @@ class TreeObjectPack(objectpack.ObjectPack):
             decl['parent_id'] = {'type': tools.int_or_none, 'default': None}
         return decl
 
+    def get_autocomplete_url(self):
+        return self.autocomplete_action.get_absolute_url()
+
 
 class TreeObjectRowsAction(objectpack.ObjectRowsAction):
     """
